@@ -175,6 +175,8 @@ class UefiAnalyzer:
         # get number of arguments
         for i in range(index, -1, -1):
             esil = res[i]["esil"].split(",")
+            if len(esil) < 4:  # fix IndexError
+                continue
             if esil[-3] == "4" and esil[-2] == "esp" and esil[-1] == "-=":
                 args_num += 1
             if (
@@ -197,21 +199,21 @@ class UefiAnalyzer:
     def strings(self) -> List[Any]:
         """Get common image properties (strings)"""
         if self._strings is None:
-            self._strings = self._r2.cmdj("izzzj")
+            self._strings = self._r2.cmdj("izzzj") or []
         return self._strings
 
     @property
     def sections(self) -> List[Any]:
         """Get common image properties (sections)"""
         if self._sections is None:
-            self._sections = self._r2.cmdj("iSj")
+            self._sections = self._r2.cmdj("iSj") or []
         return self._sections
 
     @property
     def functions(self) -> List[Any]:
         """Get common image properties (functions)"""
         if self._functions is None:
-            self._functions = self._r2.cmdj("aflj")
+            self._functions = self._r2.cmdj("aflj") or []
         return self._functions
 
     def _get_insns(self) -> List[Any]:
@@ -661,7 +663,7 @@ class UefiAnalyzer:
                     address=block_insns[index]["offset"],
                     service=pei_service.name,
                 )
-                if not ppi in ppi_list:
+                if ppi not in ppi_list:
                     ppi_list.append(ppi)
 
         return ppi_list
